@@ -1,6 +1,6 @@
 from django.db import models
 from django.db.models import Q
-from mutex.models import MutexEvent
+from dmutex.models import MutexEvent
 
 ### Base event
 class Event(MutexEvent):
